# Contributing

This Python package is developed in the context of the `Getting The Data Right` project.

If you would like to contribute or have any question [contact us](mailto:admin.gettingthedataright@aau.dk).

If you are a developer please check the [project documentation guidelines](http://bonsamurais.gitlab.io/bonsai/documentation/guidelines.html) for more general instructions.

## Installation

To install a local version of the repository execute in the command line using ssh:

```
git clone git@gitlab.com:bonsamurais/bonsai/util/dataio.git@<version>
```

Or using https:

```
git clone https://gitlab.com/bonsamurais/bonsai/util/dataio.git@<version>
```


To install locally type inside the repository folder:

```
pip install -e .
```